@@ -606,9 +606,16 @@ g_vfs_backend_invocation_first_handler (GVfsDBusMount *object,
                                         GDBusMethodInvocation *invocation,
                                         GVfsBackend *backend)
 {
-  g_debug ("backend_dbus_handler %s:%s\n",
+  GDBusConnection *connection;
+  GCredentials *credentials;
+
+  connection = g_dbus_method_invocation_get_connection (invocation);
+  credentials = g_dbus_connection_get_peer_credentials (connection);
+
+  g_debug ("backend_dbus_handler %s:%s (pid=%u)\n",
            g_dbus_method_invocation_get_interface_name (invocation),
-           g_dbus_method_invocation_get_method_name (invocation));
+           g_dbus_method_invocation_get_method_name (invocation),
+           g_credentials_get_unix_pid (credentials, NULL));
 
   if (backend->priv->block_requests)
     {
@@ -822,7 +829,10 @@ complete_unmount_with_op (UnmountWithOpData *data, gboolean no_more_processes)
     }
   else if (!data->ret)
     {
-      /*  "show-processes" signal wasn't handled, return TRUE to signal we should unmount */
+      /*  If the "show-processes" signal wasn't handled */
+      g_simple_async_result_set_error (simple, G_IO_ERROR, G_IO_ERROR_BUSY,
+                                       _("File system is busy"));
+      ret = FALSE;
     }
   else
     {
@@ -906,6 +916,8 @@ unmount_with_op_data_free (UnmountWithOpData *data)
  * gvfs_backend_unmount_with_operation_sync().
  *
  * If the operation was cancelled, G_IO_ERROR_FAILED_HANDLED will be returned.
+ * If the operation wasn't interacted and there were outstanding jobs,
+ * G_IO_ERROR_BUSY will be returned.
  *
  * Returns: %TRUE if the backend should be unmounted (either no blocking
  *     processes or the user decided to unmount anyway), %FALSE if
@@ -1041,6 +1053,7 @@ forced_unregister_mount_callback (GVfsDBusMountTracker *proxy,
   g_vfs_daemon_close_active_channels (daemon, backend);
   g_vfs_job_source_closed (G_VFS_JOB_SOURCE (backend));
 
+  g_object_unref (backend);
 }
 
 void
@@ -1048,7 +1061,7 @@ g_vfs_backend_force_unmount (GVfsBackend *backend)
 {
   g_vfs_backend_set_block_requests (backend, TRUE);
   g_vfs_backend_unregister_mount (backend,
-				  (GAsyncReadyCallback) forced_unregister_mount_callback,
-				  backend);
+                                  (GAsyncReadyCallback) forced_unregister_mount_callback,
+                                  g_object_ref (backend));
 }
 
