@@ -59,6 +59,7 @@
 #include "gvfsjobpush.h"
 #include "gvfsdaemonprotocol.h"
 #include "gvfsdaemonutils.h"
+#include "gvfsutils.h"
 
 #ifdef HAVE_AVAHI
 #include "gvfsdnssdutils.h"
@@ -1654,7 +1655,7 @@ g_mount_spec_to_dav_uri (GMountSpec *spec)
   soup_uri_set_user (uri, user);
 
   /* IPv6 host does not include brackets in SoupURI, but GMountSpec host does */
-  if (host[0] == '[')
+  if (gvfs_is_ipv6 (host))
     uri->host = g_strndup (host + 1, strlen (host) - 2);
   else
     soup_uri_set_host (uri, host);
@@ -2864,12 +2865,12 @@ do_move (GVfsBackend *backend,
                     g_vfs_job_failed_literal (G_VFS_JOB(job),
                                               G_IO_ERROR,
                                               G_IO_ERROR_WOULD_MERGE,
-                                              _("Can't move directory over directory"));
+                                              _("Can’t move directory over directory"));
                   else
                     g_vfs_job_failed_literal (G_VFS_JOB(job),
                                               G_IO_ERROR,
                                               G_IO_ERROR_IS_DIRECTORY,
-                                              _("Can't move over directory"));
+                                              _("Can’t move over directory"));
                   goto error;
                 }
               else if (source_ft == G_FILE_TYPE_DIRECTORY)
@@ -2987,7 +2988,7 @@ do_copy (GVfsBackend *backend,
                 g_vfs_job_failed_literal (G_VFS_JOB(job),
                                           G_IO_ERROR,
                                           G_IO_ERROR_WOULD_MERGE,
-                                          _("Can't copy directory over directory"));
+                                          _("Can’t copy directory over directory"));
               else
                 g_vfs_job_failed_literal (G_VFS_JOB(job),
                                           G_IO_ERROR,
@@ -3016,7 +3017,7 @@ do_copy (GVfsBackend *backend,
       g_vfs_job_failed_literal (G_VFS_JOB (job),
                                 G_IO_ERROR,
                                 G_IO_ERROR_WOULD_RECURSE,
-                                _("Can't recursively copy directory"));
+                                _("Can’t recursively copy directory"));
       goto error;
     }
 
